/*
Copyright (C) 2004-2011 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "resources.h"
#include <gccore.h>
#include <ogcsys.h>
#include <di/di.h>

#include "fat.h"

void loadSound(int index, const char *filename)
{
	audio.loadSound(index, filename);

	graphics.showLoading(1, 30);
}

void loadSprite(const char *token)
{
	Sprite *sprite;

	char name[50];
	char filename[8][100];
	int frameTime[8];

	int i;
	int hue, sat, val;

	sscanf(token, "%s %d %d %d %s %d %s %d %s %d %s %d %s %d %s %d %s %d %s %d", name, &hue, &sat, &val, filename[0], &frameTime[0], filename[1], &frameTime[1], filename[2], &frameTime[2], filename[3], &frameTime[3], filename[4], &frameTime[4], filename[5], &frameTime[5], filename[6], &frameTime[6], filename[7], &frameTime[7]);

	sprite = graphics.addSprite(name);

	i = 0;

	while (true)
	{
		if (strcmp(filename[i], "@none@") == 0)
			break;

		sprite->setFrame(i, graphics.loadImage(filename[i], hue, sat, val), frameTime[i]);

		i++;
		
		if (i == 8)
			break;
	}
}

void loadResources()
{
	graphics.resetLoading();

	audio.free();
	graphics.free();
	
	graphics.quickSprite("cheatHeader", graphics.loadImage("/apps/blob/gfx/main/cheats.png"));
	graphics.quickSprite("optionsHeader", graphics.loadImage("/apps/blob/gfx/main/options.png"));
	graphics.quickSprite("joystickHeader", graphics.loadImage("/apps/blob/gfx/main/joystickConfig.png"));
	graphics.quickSprite("keyHeader", graphics.loadImage("/apps/blob/gfx/main/keyConfig.png"));
	graphics.quickSprite("optionsBackground", graphics.loadImage("/apps/blob/gfx/main/optionsBackground.png"));

	SDL_FillRect(graphics.screen, NULL, graphics.black);

	//benoa
	SDL_Surface *pic = graphics.loadImage("/apps/blob/gfx/main/licensePic.png");
	graphics.blit(pic, 0, 0, graphics.screen, false);
	SDL_FreeSurface(pic);
	graphics.updateScreen();

	graphics.drawString(_("Loading..."), 320, 440, TXT_CENTERED, graphics.screen);

	graphics.showLoading(0, 0);
	graphics.updateScreen();	
	
	if (!engine.loadDefines())
		graphics.showErrorAndExit("Could not load map define list '%s'", "/apps/blob/data/defines.h");

	if (!engine.loadData("/apps/blob/data/mainSprites"))
		graphics.showErrorAndExit(ERR_FILE, "/apps/blob/data/mainSprites");

	char *token = strtok((char*)engine.dataBuffer, "\n");

	graphics.showLoading(10, 10);
	//benoa
	graphics.drawString(_("Parsing files... Be patient... (Remember Atari st?!)"), 320, 50, TXT_CENTERED, graphics.screen);
	graphics.updateScreen();
	//while (true)
	while (strcmp(token, "@EOF@") != 0)
	{
		/*if (strcmp(token, "@EOF@") == 0)
		{
			break;
		}*/

		loadSprite(token);
		token = strtok(NULL, "\n");
	}

	//benoa
	graphics.drawString(_("Loading sounds..."), 320, 70, TXT_CENTERED, graphics.screen);
	graphics.updateScreen();
	graphics.showLoading(40, 40);

	loadSound(SND_WATERIN, "/apps/blob/sound/waterIn");
	loadSound(SND_WATEROUT, "/apps/blob/sound/waterOut");
	loadSound(SND_ITEM, "/apps/blob/sound/item");
	loadSound(SND_PISTOL, "/apps/blob/sound/pistol");
	loadSound(SND_RICO1, "/apps/blob/sound/rico1");
	loadSound(SND_RICO2, "/apps/blob/sound/rico2");
	loadSound(SND_MACHINEGUN, "/apps/blob/sound/machinegun");
	loadSound(SND_DEATH1, "/apps/blob/sound/death1");
	loadSound(SND_DEATH2, "/apps/blob/sound/death2");
	loadSound(SND_DEATH3, "/apps/blob/sound/death3");
	loadSound(SND_GRENADE, "/apps/blob/sound/grenade");
	loadSound(SND_ROCKET, "/apps/blob/sound/rocket");
	loadSound(SND_FIREBALL, "/apps/blob/sound/fireball");
	loadSound(SND_HIT, "/apps/blob/sound/punch");
	loadSound(SND_SPLAT, "/apps/blob/sound/splat");
	loadSound(SND_POP, "/apps/blob/sound/pop1");
	loadSound(SND_TELEPORT1, "/apps/blob/sound/teleport1");
	loadSound(SND_TELEPORT2, "/apps/blob/sound/teleport2");
	loadSound(SND_TELEPORT3, "/apps/blob/sound/teleport3");
	loadSound(SND_GETWEAPON, "/apps/blob/sound/weaponPickup");
	loadSound(SND_LASER, "/apps/blob/sound/laser");
	loadSound(SND_ELECDEATH1, "/apps/blob/sound/elecDeath1");
	loadSound(SND_ELECDEATH2, "/apps/blob/sound/elecDeath2");
	loadSound(SND_ELECDEATH3, "/apps/blob/sound/elecDeath3");
	loadSound(SND_LOCKEDDOOR, "/apps/blob/sound/doorLocked");
	loadSound(SND_OPENDOOR, "/apps/blob/sound/doorOpen");
	loadSound(SND_DOOROPENED, "/apps/blob/sound/doorOpened");
	loadSound(SND_SWITCH1, "/apps/blob/sound/switch");
	loadSound(SND_SWITCH2, "/apps/blob/sound/switch");
	loadSound(SND_DROWNING, "/apps/blob/sound/drowning");
	loadSound(SND_GULP, "/apps/blob/sound/gulp");
	loadSound(SND_EAT, "/apps/blob/sound/eat");
	loadSound(SND_THROW, "/apps/blob/sound/throw");
	loadSound(SND_GRBOUNCE, "/apps/blob/sound/grenadeBounce");
	loadSound(SND_SPREADGUN, "/apps/blob/sound/plasma");
	loadSound(SND_STONEBREAK, "/apps/blob/sound/stoneBreak");
	loadSound(SND_ELECTRICITY1, "/apps/blob/sound/electricity1");
	loadSound(SND_ELECTRICITY2, "/apps/blob/sound/electricity2");
	loadSound(SND_ELECTRICITY3, "/apps/blob/sound/electricity3");
	loadSound(SND_CLANG, "/apps/blob/sound/clang");
	loadSound(SND_FIRECRACKLE, "/apps/blob/sound/fireCrackle");
	loadSound(SND_CLOCK, "/apps/blob/sound/clock");

	//benoa
	graphics.drawString(_("Loading map..."), 320, 90, TXT_CENTERED, graphics.screen);
	graphics.updateScreen();

	loadDefWeapons();

	graphics.showLoading(45, 45);

	loadDefEnemies();

	graphics.showLoading(50, 50);

	loadDefItems();
	
	graphics.showLoading(55, 55);

	graphics.loadMapTiles("/apps/blob/gfx/common");

	//graphics.drawString(_(" loadMapTiles..."), 320, 110, TXT_CENTERED, graphics.screen);
	//graphics.updateScreen();

	player.setSprites(graphics.getSprite("BobRight", true), graphics.getSprite("BobLeft", true), graphics.getSprite("BobSpin", true));

	graphics.showLoading(90, 90);

	graphics.drawString(_(game.mapName), 320, 130, TXT_CENTERED, graphics.screen);
	graphics.updateScreen();

	loadMapData(game.mapName);


	graphics.showLoading(100, 100);
	graphics.delay(100);
	#if USEPAK
	graphics.showLoading(100, 100);
	graphics.delay(100);
	#endif

	createBoss(game.stageName);
	
	game.canContinue = 0;

	// We don't need this anymore. Remove it to free up some memory...
	engine.defineList.clear();
}
